ad_page_contract {

    Main view page for projects.
    
    @author jader@bread.com
    @author ncarroll@ee.usyd.edu.au (on first version that used CR)
    @creation-date 2003-05-15
    @cvs-id $Id: index.tcl,v 1.9.2.12 2004/03/12 00:20:24 jader Exp $

    @return title Page title.
    @return context Context bar.
    @return projects Multirow data set of projects.
    @return task_term Terminology for tasks
    @return task_term_lower Terminology for tasks (lower case)
    @return project_term Terminology for projects
    @return project_term_lower Terminology for projects (lower case)

} {
    orderby_project:optional
    {status_id:integer,optional}
    category_id:multiple,optional
    {format "normal"}
} -properties {

    context:onevalue
    projects:multirow
    write_p:onevalue
    create_p:onevalue
    admin_p:onevalue
    task_term:onevalue
    task_term_lower:onevalue
    project_term:onevalue
    project_term_lower:onevalue
}

# --------------------------------------------------------------- #

# terminology
set task_term       [parameter::get -parameter "TaskName" -default "Task"]
set task_term_lower [parameter::get -parameter "taskname" -default "task"]
set project_term    [parameter::get -parameter "ProjectName" -default "Project"]
set project_term_lower [parameter::get -parameter "projectname" -default "project"]

# set up context bar
set context [list]

# the unique identifier for this package
set package_id [ad_conn package_id]
set user_id    [ad_maybe_redirect_for_registration]

# permissions
permission::require_permission -party_id $user_id -object_id $package_id -privilege read

set write_p  [permission::permission_p -object_id $package_id -privilege write] 
set create_p [permission::permission_p -object_id $package_id -privilege create]
set admin_p [permission::permission_p -object_id $package_id -privilege admin]

# root CR folder
set root_folder [db_string get_root "select pm_project__get_root_folder (:package_id, 'f')"]

# Projects, using list-builder ---------------------------------

# set default values
if {![exists_and_not_null status_id]} {
    set status_id [pm::project::default_status_open]
}

# Categories are arranges into category trees. 
# Set up an array for each tree. The array contains the category for each tree

db_foreach get_choices {
    select 
    t.name as cat_name, 
    t.category_id as cat_id, 
    tm.tree_id 
    from 
    category_tree_map tm, 
    categories c, 
    category_translations t 
    where 
    c.tree_id      = tm.tree_id and 
    c.category_id  = t.category_id and 
    tm.object_id   = :package_id and
    c.deprecated_p = 'f'
    order 
    by t.name
} {
    lappend category_choices($tree_id) [list $cat_name $cat_id]
}

# We want to set up a filter for each category tree.

set export_vars [export_vars -form {status_id orderby}]

set category_select ""

foreach tree_list [db_list_of_lists get_category_trees {
    select 
    tt.name as tree_name, 
    tt.tree_id 
    from 
    category_tree_map tm, 
    category_tree_translations tt 
    where 
    tm.object_id = :package_id and 
    tm.tree_id = tt.tree_id
}] {
    
    set tree_name [lindex $tree_list 0]
    set tree_id   [lindex $tree_list 1]

    if {![exists_and_not_null category_choices($tree_id)]} {
        set category_choices($tree_id) [list]
    }



    append category_select "<form method=\"post\" action=\"index\">$export_vars $tree_name: <br /><select name=\"category_id\"><option value=\"\">--Select All--</option>"

    foreach cat_item $category_choices($tree_id) {
        set cat_name [lindex $cat_item 0]
        set cat_id   [lindex $cat_item 1]

        if {[exists_and_not_null category_id] && [lsearch $category_id $cat_id] != -1} {
            set select "selected"
        } else {
            set select ""
        }

        append category_select "<option $select value=\"$cat_id\">$cat_name</option>"
    }

    append category_select "</select><input type=\"submit\" value=\"Go\" /></form>"
}


template::list::create \
    -name projects \
    -multirow projects \
    -key project_item_id \
    -elements {
        customer_name {
            label "Customer"
            display_template "
<if @projects.organization_id@ not nil><a href=\"/organization/one?organization_id=@projects.organization_id@\">@projects.customer_name@</a></if><else>@projects.customer_name@</else>
"
        }
        project_name {
            label "Project name"
            link_url_col item_url
            link_html { title "View this project version" }
        }
        earliest_finish_date {
            label "Earliest finish"
            display_template "<if @projects.days_to_earliest_finish@ gt 1>@projects.earliest_finish_date@</if><else><font color=\"green\">@projects.earliest_finish_date@</font></else>"
        }
        latest_finish_date {
            label "Latest Finish"
            display_template "<if @projects.days_to_latest_finish@ gt 1>@projects.latest_finish_date@</if><else><font color=\"red\">@projects.latest_finish_date@</font></else>"
        }
        actual_hours_completed {
            label "Hours completed"
            display_template "@projects.actual_hours_completed@/@projects.estimated_hours_total@"
        }
        category_id {
            label "Categories"
            display_template "<group column=\"project_item_id\"><li>@projects.category_name@</group>"
        }
    } \
    -actions [list "Add project" "add-edit" "Add project" "Customers" "[site_node::get_package_url -package_key organizations]" "View customers"] \
    -sub_class {
        narrow
    } \
    -filters {
        status_id {
            label "Status" 
            values {[db_list_of_lists get_status "select description, status_id from pm_project_status order by status_type desc, description"]}
            where_clause {s.status_id = :status_id}
        }
        category_id {
            label Categories
            where_clause {c.category_id = [join [value_if_exists category_id] ","]}
        }
    } \
    -orderby {
        default_value project_name,asc
        project_name {
            label "Project name"
            orderby_desc "upper(p.title) desc"
            orderby_asc "upper(p.title) asc"
            default_direction asc
        }
        customer_name {
            label "Customer Name"
            orderby_desc "upper(o.name) desc, earliest_finish_date desc"
            orderby_asc "upper(o.name) asc, earliest_finish_date asc"
            default_direction asc
        }
        category_id {
            label "Categories"
            orderby_desc "c.category_name desc"
            orderby_asc "c.category_name asc"
            default_direction asc
        }
        earliest_finish_date {
            label "Earliest finish"
            orderby_desc "p.earliest_finish_date desc"
            orderby_asc "p.earliest_finish_date asc"
            default_direction asc
        }
        latest_finish_date {
            label "Latest finish"
            orderby_desc "p.latest_finish_date desc"
            orderby_asc "p.latest_finish_date asc"
            default_direction asc
        }
        actual_hours_completed {
            label "Hours completed"
            orderby_desc "p.actual_hours_completed desc"
            orderby_asc "p.actual_hours_completed asc"
            default_direction asc
        }
    } \
    -formats {
        normal {
            label "Table"
            layout table
            row {
                project_name {}
                customer_name {}
                category_id {}
                earliest_finish_date {}
                latest_finish_date {}
                actual_hours_completed {}
            }
        } 
        csv {
            label "CSV"
            output csv
            page_size 0
            row {
                project_name {}
                customer_name {}
                category_id {}
                earliest_finish_date {}
                latest_finish_date {}
                actual_hours_completed {}
            }
        } 
    } \
    -orderby_name orderby_project \
    -html {
        width 100%
    }


db_multirow -extend { item_url } projects project_folders {
} {
    set item_url [export_vars -base "one" {project_item_id}]
}


# This spits out the CSV if we happen to be in CSV layout

if {[string equal $format csv]} {
    #set csv [list::write_output -name pan]
    #set outputheaders [ns_conn outputheaders]
    #ns_set cput $outputheaders "Content-Disposition" "attachment; filename=pan.csv"
    #doc_return 200 "application/text" "$csv"

    # set csv [list::write_output -name projects]

    set outputheaders [ns_conn outputheaders]
    ns_set cput $outputheaders "Content-Disposition" "attachment; filename=projects.xls"

    # ns_log Notice "csv: $csv"

    list::write_output -name projects

    # doc_return 200 application/vnd.ms-excel $csv
    # ns_return 200 application/vnd.ms-excel $csv

}


# ------------------------- END OF FILE ------------------------- #
