ad_page_contract {
    Main view page for one project. Also shows logged time, and allows a 
    user to log time

    @author jader@bread.com, ncarroll@ee.usyd.edu.au
    @creation-date 2003-05-15
    @cvs-id $Id: one.tcl,v 1.26.2.11 2004/03/12 00:20:24 jader Exp $

    @return context Context bar.
    @return versions a multirow holding versions of the project
    @return live_revision the project_id of the live_revision

    @param project_name
    @param project_code
    @param project_folder_id
    @param goal
    @param description
    @param planned_start_date
    @param planned_end_date
    @param ongoing_p
    @param use_goal_p Specifies whether or not to include the goal field 1 = yes
    @param use_project_code_p Specifies whether or not to show the user-specified project code 1 = yes
    @param use_uncertain_completion_times_p Specifies whether or not to use PERT style uncertainty times 1 = yes
} {

    project_item_id:integer,optional
    project_id:integer,optional
    {orderby_subproject ""}
    {orderby_tasks ""}
    {orderby_versions ""}

} -properties {
    categories:onelist
    context:onevalue
    project:multirow
    tasks:multirow
    people:multirow
    write_p:onevalue
    create_p:onevalue
    versions:multirow   
    custom:multirow
    parent_task_id:onevalue
    task_type:onevalue
    project_id:onevalue
    use_goal_p:onevalue
    use_project_code_p:onevalue
    use_uncertain_completion_times_P:onevalue
    use_project_customizations_p:onevalue
    task_term:onevalue
    then_ansi:onevalue
    edit_url:onevalue
    comments:onevalue
    comments_link:onevalue
} -validate {
    project_item_id_exists {
        if {![exists_and_not_null project_item_id]} {
            set project_item_id [pm::project::get_project_item_id \
                                     -project_id $project_id]
        }
    }
    project_id_exists {
        if {![exists_and_not_null project_id]} {
            set project_id [pm::project::get_project_id \
                                -project_item_id $project_item_id]
        }
    }
}

set original_project_id $project_id

# --------------------------------------------------------------- #

# the unique identifier for this package
set package_id [ad_conn package_id]
set user_id    [ad_maybe_redirect_for_registration]

# ----------------
# general comments
# ----------------
set comments [general_comments_get_comments -print_content_p 1 -print_attachments_p 1 $project_item_id "[ad_conn url]?project_item_id=$project_item_id"]

set comments_link [general_comments_create_link -object_name cr_items -link_text "Add a comment" -context_id $package_id $project_item_id "[ad_conn url]?project_item_id=$project_item_id"]


# terminology
set project_term       [parameter::get -parameter "ProjectName" -default "Project"]
set project_term_lower [parameter::get -parameter "projectname" -default "project"]
set task_term          [parameter::get -parameter "TaskName" -default "Task"]
set use_goal_p         [parameter::get -parameter "UseGoalP" -default "1"]
set use_project_code_p [parameter::get -parameter "UseUserProjectCodesP" -default "1"]
set use_uncertain_completion_times_p [parameter::get -parameter "UseUncertainCompletionTimesP" -default "1"]
set use_project_customizations_p [parameter::get -parameter "UseProjectCustomizationsP" -default "0"]

# permissions
permission::require_permission -party_id $user_id -object_id $package_id -privilege read

set write_p  [permission::permission_p -object_id $package_id -privilege write] 
set create_p [permission::permission_p -object_id $package_id -privilege create]


# categories

set categories [list]
set cat_list [category::get_mapped_categories $project_item_id]
foreach cat $cat_list {
    lappend categories [category::get_name $cat]
}

db_1row project_query { } -column_array project
set project_root [db_exec_plsql get_root_folder { }]

set project(planned_start_date) [lc_time_fmt $project(planned_start_date) "%x"]
set project(planned_end_date)   [lc_time_fmt $project(planned_end_date) "%x"]
set project(estimated_finish_date) [lc_time_fmt $project(estimated_finish_date) "%x"]
set project(earliest_finish_date) [lc_time_fmt $project(earliest_finish_date) "%x"]
set project(latest_finish_date) [lc_time_fmt $project(latest_finish_date) "%x"]
set project(logger_variable_id) [logger::variable::get_default_variable_id]

set log_url "[ad_conn package_url]log?project_id=$project(logger_project)&pm_project_id=$project_item_id"

set then_ansi [db_string get_now_julian "select to_char(current_timestamp - '30 days'::INTERVAL,'YYYY-MM-DD')"]


set log_note "Last 30 days"



set edit_url "[ad_conn package_url]add-edit?[export_url_vars project_item_id]"

# set up context bar, needs parent_id

if {[string equal $project(parent_id) $project_root]} {
    set context [list "View"]
} else {
    set context [list [list "one?project_item_id=$project(parent_id)" "Parent"] "View"]
}

# Tasks, using list-builder ---------------------------------

if {$use_uncertain_completion_times_p} {
    set work_display_template "@tasks.estimated_hours_work_min@ - @tasks.estimated_hours_work_max@ h"
} else {
    set work_display_template "@tasks.estimated_hours_work@ h"
}

set process_link "process-use?project_item_id=$project_item_id"

template::list::create \
    -name tasks \
    -multirow tasks \
    -key task_id \
    -elements {
        task_id {
            label "ID"
        }
        title {
            label "Subject"
            display_col title
            display_template {
                <a href="@tasks.item_url@">@tasks.title@</a>
            }
        } 
        parent_task_id {
            label "Dep"
            display_template {
                <a href="task-one?task_id=@tasks.parent_task_id@">@tasks.parent_task_id@</a>
            }
        }
        slack_time {
            label "Slack"
            display_template "<font size=\"-2\" color=\"grey\"><if @tasks.slack_time@>@tasks.slack_time@</if></font>"
        }
        earliest_start {
            label "Earliest Start"
            display_template "<if @tasks.days_to_earliest_start@ gt 1>@tasks.earliest_start_pretty@</if><else><font color=\"green\">@tasks.earliest_start_pretty@</font></else>"
        }
        earliest_finish {
            label "Earliest Finish"
            display_template "<if @tasks.days_to_earliest_finish@ gt 1>@tasks.earliest_finish_pretty@</if><else><font color=\"green\">@tasks.earliest_finish_pretty@</font></else>"
        }
        latest_start {
            label "Latest Start"
            display_template "<if @tasks.days_to_latest_start@ gt 1>@tasks.latest_start_pretty@</if><else><font color=\"red\">@tasks.latest_start_pretty@</font></else>"
        }
        latest_finish {
            label "Latest Finish"
            display_template "<if @tasks.days_to_latest_finish@ gt 1>@tasks.latest_finish_pretty@</if><else><font color=\"red\">@tasks.latest_finish_pretty@</font></else>"
        }
        last_name {
            label "Who"
            display_template {
                <group column="task_id">@tasks.first_names@&nbsp;@tasks.last_name@<br></group>
            }

        }
    } \
    -actions [list "Use process" $process_link "Use a process"] \
    -bulk_actions {
        "Edit" "task-add-edit" "Edit tasks"
    } \
    -bulk_action_export_vars {
        project_item_id
        project_id
        {my_key 1}
    } \
    -sub_class {
        narrow
    } \
    -filters {
        project_item_id {}
        orderby_subproject {}
        orderby_versions {}
        orderby_people {}
    } \
    -orderby {
        title {orderby title}
        earliest_start {orderby earliest_start}
        earliest_finish {orderby earliest_finish}
        latest_start {orderby latest_start}
        latest_finish {orderby latest_finish}
        default_value latest_start,asc
    } \
    -orderby_name orderby_tasks \
    -html {
    }


db_multirow -extend { item_url earliest_start_pretty earliest_finish_pretty latest_start_pretty latest_finish_pretty slack_time} tasks project_tasks_query {
} {
    set item_url [export_vars -base "task-one" { revision_id task_id}]

    set earliest_start_pretty [lc_time_fmt $earliest_start "%x"]
    set earliest_finish_pretty [lc_time_fmt $earliest_finish "%x"]
    set latest_start_pretty [lc_time_fmt $latest_start "%x"]
    set latest_finish_pretty [lc_time_fmt $latest_finish "%x"]

    set slack_time [pm::task::slack_time \
                        -earliest_start_j $earliest_start_j \
                        -today_j $today_j \
                        -latest_start_j $latest_start_j]
                    
}



# Subprojects, using list-builder ---------------------------------

db_multirow subproject project_subproject_query { }

template::list::create \
    -name subproject \
    -multirow subproject \
    -key item_id \
    -elements {
        project_name {
            label "Subject"
            link_url_col item_url
            link_html { title "View this subproject" }
        }
        actual_hours_completed {
            label "Hours completed"
        }
    } \
    -sub_class {
        narrow
    } \
    -filters {
        project_item_id {}
        orderby_versions {}
        orderby_tasks {}
        orderby_people {}
        orderby_versions {}
    } \
    -orderby {
        project_name {orderby project_name}
        default_value project_name,desc
    } \
    -orderby_name orderby_subproject \
    -html {
        width 100%
    }



db_multirow -extend { item_url } subproject project_subproject_query {
} {
    set item_url [export_vars -base "one" -override {{project_item_id $item_id}} {project_item_id}]
}


# People, using list-builder ---------------------------------

db_multirow people project_people_query { }

template::list::create \
    -name people \
    -multirow people \
    -key item_id \
    -elements {
        party_id {
            label "Who"
        }
        role_id {
            label "Role"
        }
    } \
    -sub_class {
        narrow
    } \
    -filters {
        party_id {}
        orderby_subproject {}
        orderby_versions {}
        orderby_tasks {}
    } \
    -orderby {
        role_id {orderby role_id}
        default_value role_id,desc
    } \
    -orderby_name orderby_subproject \
    -html {
        width 100%
    }



db_multirow -extend { item_url } subproject project_subproject_query {
} {
    set item_url [export_vars -base "one" -override {{project_item_id $item_id}} {project_item_id}]
}



# Project versions, using list-builder ---------------------------------

db_multirow versions project_versions { }

template::list::create \
    -name versions \
    -multirow versions \
    -key item_id \
    -elements {
        project_id {
            label "Version"
            link_url_col item_url
            link_html { title "View this project version" }
        }
        project_name {
            label "Subject"
        }
        planned_end_date {
            label "Deadline"
        }
    } \
    -sub_class {
        narrow
    } \
    -filters {
        project_item_id {}
        orderby_subproject {}
        orderby_people {}
        orderby_tasks {}
    } \
    -orderby {
        project_name {orderby project_name}
        default_value project_name,desc
    } \
    -orderby_name orderby_versions \
    -html {
        width 100%
    }


db_multirow -extend { item_url } versions project_versions {
} {
    set item_url [export_vars -base "one" -override {{project_item_id $item_id}} {project_id}]

    
}


# -------------------------CUSTOMIZATIONS--------------------------
# If there are customizations, put them in a multirow called custom
# -----------------------------------------------------------------

db_1row custom_query { } -column_array custom 


# end of customizations


# -----------------------------------------------------------------
# Logger forms and so on - shows time logged, and allows you to log
# other time
# -----------------------------------------------------------------



ad_return_template
# ------------------------- END OF FILE ------------------------- #
