ad_page_contract {

    Add/edit form for process tasks, page 2

    @author jader@bread.com
    @creation-date 2003-09-29
    @cvs-id $Id: process-task-add-edit-2.tcl,v 1.4.2.8 2004/03/12 00:20:24 jader Exp $

    @param process_id The process that we're adding or editing items for.
    @param task_title The titles of the tasks
    @param estimated_hours_work Estimated hours worked
    @param estimated_hours_work Estimated hours worked (min)
    @param estimated_hours_work Estimated hours worked (max)
    @param process_task_id the ID for each process
    @param use_dependency this task will depend on others

} {

    process_id:integer,notnull
    {task_title:multiple ""}
    {description:multiple ""}
    {estimated_hours_work:multiple ""}
    {estimated_hours_work_min:multiple ""}
    {estimated_hours_work_max:multiple ""}
    process_task_id:integer,multiple
    {use_dependency:integer,multiple ""}

} -validate {
    process_id_missing {
        if {![exists_and_not_null process_id]} {
            ad_complain
        }
    }
    task_title_too_long {
        foreach tt $task_title {
            if {[string length $tt] > 198} {
                ad_complain
            }
        }
    }
    description_too_long {
        foreach d $description {
            if {[string length $d] > 3998} {
                ad_complain
            }
        }
    }
    bad_estimated_hours_work_range {
        foreach wr $estimated_hours_work {
            if {$wr > 500 || $wr < 0} {
                ad_complain
            }
        }
    }
    process_task_id_missing {
        foreach ptid $process_task_id {
            if {![exists_and_not_null ptid]} {
                ad_complain
            }
        }
    }
} -errors {
    process_id_missing {I don't know which process these tasks are for!}
    task_title_too_long {A task subject is too long. It must be 198 characters or less}
    description_too_long {A description subject is too long. It must be 3998 characters or less}
    bad_estimated_hours_work_range {The estimated hours must be between 0 and 499 hours}
    process_task_id_missing {I don't know which process task is being added or edited!}
}


set user_id    [ad_maybe_redirect_for_registration]
set package_id [ad_conn package_id]

permission::require_permission -party_id $user_id -object_id $package_id -privilege create

set use_uncertain_completion_times_p [parameter::get -parameter "UseUncertainCompletionTimesP" -default "1"]


# ------------------------------------------------------------
# we need to determine if these tasks are new or being edited.
# we know this by checking if the numbers exist.
# we assume that if any of them exist, that we're editing.
# ------------------------------------------------------------

set edit_p [db_string editing_process_tasks_p { } -default "0"]


if {[string equal $edit_p "0"]} {

    # -----------------------------
    # if we're adding process tasks
    # -----------------------------

    set index 0
    foreach ptid $process_task_id {
        
        # set up the values
        set task_id  [lindex $process_task_id $index]
        
        set one_line [lindex $task_title      $index]
        set desc     [lindex $description     $index]
        
        if {[string equal $use_uncertain_completion_times_p "1"]} {
            set work_min [lindex $estimated_hours_work_min $index]
            set work_max [lindex $estimated_hours_work_max $index]
            set work [expr .5 * [expr $work_max - $work_min] + $work_min]
        } else {
            set work     [lindex $estimated_hours_work $index]
            set work_min $work
            set work_max $work
        }
        
        db_dml new_task { *SQL* }
        incr index
    }
} else {

    # -----------------------------
    # if we're editing process tasks
    # -----------------------------

    # -----------------------------
    # if we're adding process tasks
    # -----------------------------

    set index 0
    foreach ptid $process_task_id {
        
        # set up the values
        set task_id  [lindex $process_task_id $index]
        
        set one_line [lindex $task_title      $index]
        set desc     [lindex $description     $index]
        
        if {[string equal $use_uncertain_completion_times_p "1"]} {
            set work_min [lindex $estimated_hours_work_min $index]
            set work_max [lindex $estimated_hours_work_max $index]
            set work [expr .5 * [expr $work_max - $work_min] + $work_min]
        } else {
            set work     [lindex $estimated_hours_work $index]
            set work_min $work
            set work_max $work
        }
        
        db_dml edit_task { *SQL* }
        incr index
    }
}

if {1 == 0} {

    set revision_has_dependencies [list]
    set revision_no_dependencies  [list]

    for {set i 1} {$i <= $number} {incr i} {
 
        if {![exists_and_not_null estimated_hours_work($i)]} {
            set estimated_hours_work($i) [expr .5 * ($estimated_hours_work_max($i) - $estimated_hours_work_min($i)) + $estimated_hours_work_min($i)]
        }

        if {![exists_and_not_null estimated_hours_work_min($i)]} {
            set estimated_hours_work_min($i) $estimated_hours_work($i)
        }

        if {![exists_and_not_null estimated_hours_work_max($i)]} {
            set estimated_hours_work_max($i) $estimated_hours_work($i)
        }

        # do the actual edit
        db_dml edit_task { }

        if {[info exists use_dependency_p($i)] && [string equal $use_dependency_p($i) "t"]} {
            lappend revision_has_dependencies $this_revision_id
        } else {
            lappend revision_no_dependencies  $this_revision_id
        }

    }

}


ad_returnredirect "process-task-assign-add-edit?[export_vars -url {use_dependency:multiple process_id process_task_id:multiple}]"
ad_script_abort
