ad_page_contract {

    Add/edit form for process tasks

    @author jader@bread.com
    @creation-date 2003-09-25
    @cvs-id $Id: process-task-add-edit.tcl,v 1.6.2.8 2004/03/12 00:20:24 jader Exp $

    @return context_bar Context bar.
    @return title Page title.
    @return process_id The process we're adding/editing tasks for

    @return num used as a multirow datasource to iterate over the form elements

    @param process_id The process that we're adding or editing items for.
    @param number The number of Tasks to create

    @param process_task_id If we are editing tasks, this will be the value we receive
} {

    process_id:integer,notnull
    {number:integer "1"}
    {process_task_id:integer,multiple ""}

} -properties {

    context_bar:onevalue
    onevalue:multirow
    title:onevalue
    process_id:onevalue
    num:multirow
    use_uncertain_completion_times_p:onevalue

} -validate {
    number_is_in_range -requires {number:integer} {
        # todo: make 100 a parameter
        if {$number < 1 || $number > 100} {
            ad_complain
        }
    }
} -errors {
    number_is_in_range {Number must be between 1 and 100}
}

# --------------------------------------------------------------- #

# -----------
# terminology
# -----------

set task_term       [parameter::get -parameter "TaskName" -default "Task"]
set task_term_lower [parameter::get -parameter "taskname" -default "task"]
set use_uncertain_completion_times_p [parameter::get -parameter "UseUncertainCompletionTimesP" -default "1"]

# --------------------------------------
# the unique identifier for this package
# --------------------------------------

set package_id [ad_conn package_id]
set user_id    [ad_maybe_redirect_for_registration]

# -----------
# permissions
# -----------
permission::require_permission -party_id $user_id -object_id $package_id -privilege read

# ------------------------------------------------------------
# if process_task_id is set, then we are editing process tasks
# ------------------------------------------------------------


if {[exists_and_not_null process_task_id]} {


    set edit_p 1
    set title "Edit a process $task_term_lower"
    set context_bar [ad_context_bar [list "process-one?process_id=$process_id" "One"] "Edit tasks"]
    permission::require_permission -party_id $user_id -object_id $package_id -privilege write

    set process_tasks [list]
    set i 1
    
    db_foreach get_process_tasks { } {
        set process_task_v($i)             $pti
        set one_line_v($i)                 $one_line
        set description_v($i)              $description
        set estimated_hours_work_v($i)     $estimated_hours_work
        set estimated_hours_work_min_v($i) $estimated_hours_work_min
        set estimated_hours_work_max_v($i) $estimated_hours_work_max

        if {[exists_and_not_null dependency_type]} {
            set checked_v($i) "checked"
        } else {
            set checked_v($i) ""
        }
        
        lappend process_tasks $pti
        incr i
    }
    set number [llength $process_tasks]
} else {

    set edit_p 0
    set title "Add a process $task_term_lower"
    set context_bar [ad_context_bar [list "process-one?process_id=$process_id" "One"] "Add tasks"]
    permission::require_permission -party_id $user_id -object_id $package_id -privilege create
    
    for {set i 1} {$i <= $number} {incr i} {
        set process_task_v($i)             ""
        set one_line_v($i)                 ""
        set description_v($i)              ""
        set estimated_hours_work_v($i)     ""
        set estimated_hours_work_min_v($i) ""
        set estimated_hours_work_max_v($i) ""
        set checked_v($i)                  ""
    }
}



template::multirow create num process_task_id one_line description work work_min work_max checked

for {set i 1} {$i <= $number} {incr i} {

    if {[string equal $edit_p "0"]} {
        set process_task_id_tmp [db_nextval pm_process_task_seq]
    } else {
        set process_task_id_tmp [lindex $process_task_id [expr $i-1]]
    }

    template::multirow append num $process_task_id_tmp $one_line_v($i) $description_v($i) $estimated_hours_work_v($i) $estimated_hours_work_min_v($i) $estimated_hours_work_max_v($i) $checked_v($i)

}





