ad_page_contract {

    Form to add and edit assignments to a task

    @author jader@bread.com
    @creation-date 2003-09-10
    @cvs-id $Id: task-assign-add-edit.tcl,v 1.5.2.9 2004/03/12 00:20:24 jader Exp $

    @return context_bar Context bar.
    @return title Page title.
    @return num a multirow that contains the number of assignments
    @return tasks a multirow that contains the ticket info

    @param task_id the list of tasks we want to assign people to
    @param task_revisions the list of tasks that want dependencies assigned. Passed on to dependency-add-edit

} {

    my_key:integer,optional
    {process_task_id:multiple,optional ""}
    task_id:multiple,optional
    revisions:multiple
    {project_item_id:integer ""}
    role_id:array,optional
    party_id:array,optional

} -properties {

    tasks:multirow
    num:multirow
    context_bar:onevalue
    title:onevalue
    task_term_lower:onevalue
    project_item_id:onevalue

}

# --------------------------------------------------------------- #


# hack to get around lack of multiple hidden support with ad_form

set process_task_id [string map {"-" " "} $process_task_id]
set revisions       [string map {"-" " "} $revisions]
set task_id         [string map {"-" " "} $task_id]

db_multirow tasks get_task_info { }

# create a multirow we can use to iterate
template::multirow create num number 

# currently hardcoded the number of assignments

for {set i 0} {$i <= 5} {incr i} {
    template::multirow append num $i 
}



# terminology
set project_term    [parameter::get -parameter "ProjectName" -default "Project"]
set task_term       [parameter::get -parameter "TaskName"    -default "Task"]
set task_term_lower [parameter::get -parameter "taskname"    -default "task"]
set use_uncertain_completion_times_p [parameter::get -parameter "UseUncertainCompletionTimesP" -default "0"]

# the unique identifier for this package
set package_id [ad_conn package_id]
set user_id    [ad_maybe_redirect_for_registration]

# permissions

set title "Add $task_term_lower assignments"
set context_bar [ad_context_bar [list "one?project_item_id=$project_item_id" "One $project_term"] "New $task_term dependency"]
permission::require_permission -party_id $user_id -object_id $package_id -privilege create


set users_lofl "{{--Select Person--} {}} "
append users_lofl [db_list_of_lists get_users { }]


set roles_lofl "{{--Select Role--} {}} "
append roles_lofl [db_list_of_lists get_roles { }]

set process_task_id_pass [string map {" " "-"} $process_task_id]
set revisions_pass       [string map {" " "-"} $revisions]
set task_id_pass         [string map {" " "-"} $task_id]

ad_form -name add_edit -form {
    
    my_key:key(acs_object_id_seq)

    {process_task_id:text(hidden)
        {value $process_task_id_pass}}

    {revisions:text(hidden)
        {value $revisions_pass}}

    {task_id:text(hidden)
        {value $task_id_pass}}

    {project_item_id:text(hidden)
        {value $project_item_id}}
    
   
} -on_submit {

    set user_id [ad_conn user_id]
    set peeraddr [ad_conn peeraddr]

} -new_data {

    #role_id 
    #party_id

    set process_task_id [string map {"-" " "} $process_task_id]
    set revisions       [string map {"-" " "} $revisions]
    set task_id         [string map {"-" " "} $task_id]

    db_foreach get_more_task_info {} { 
        set one_lines($item_id)          $one_line
        set descriptions($item_id)       $description
        set end_dates_pretty($item_id)   [lc_time_fmt $end_date_ansi "%x"]
        set est_hours_work($item_id)     $estimated_hours_work
        set est_hours_work_min($item_id) $estimated_hours_work_min
        set est_hours_work_max($item_id) $estimated_hours_work_max
        set earliest_starts($item_id)    [lc_time_fmt $earliest_start_ansi "%x"]
        set earliest_finishes($item_id)  [lc_time_fmt $earliest_finish_ansi "%x"]
        set latest_starts($item_id)      [lc_time_fmt $latest_start_ansi "%x"]
        set latest_finishes($item_id)    [lc_time_fmt $latest_finish_ansi "%x"]

    }

    if {[info exists role_id]} {
        
        set searchToken [array startsearch role_id]
        
        while {[array anymore role_id $searchToken]} {
            
            set keyname   [array nextelement role_id $searchToken]
            set keyvalu   $role_id($keyname)
            
            # keyname looks like 2308.1 - 2308.10
            # first element is task_id, second is 1-10
            # if keyvalu is not empty, then we pay attention to it.

            if {[exists_and_not_null keyvalu]} {

                regexp {(.*)\.(.*)} $keyname match task_id_val num_value

                set assignment_role($task_id_val,$num_value) $keyvalu

            }            
        }
        
    }

    set party_list [list]

    if {[info exists party_id]} {
        
        set searchToken [array startsearch party_id]
        
        while {[array anymore party_id $searchToken]} {
            
            set keyname   [array nextelement party_id $searchToken]
            set keyvalu   $party_id($keyname)
            
            # keyname looks like 2308.1 - 2308.10
            # first element is task_id, second is 1-10
            # if keyvalu is not empty, then we pay attention to it.

            if {[exists_and_not_null keyvalu]} {

                regexp {(.*)\.(.*)} $keyname match task_id_val num_value

                set assignment_party($task_id_val,$num_value) $keyvalu

                lappend party_list "$task_id_val,$num_value"

            }            
        }
      
    }

    db_dml delete_assignments { }

    set project_name [db_string get_project_name { } -default "N/A"]

    # set up role names
    foreach r [db_list_of_lists get_roles { }] {
        set des [lindex $r 0]
        set val [lindex $r 1]
        set role_oneline($val) $des
    }

    foreach pl $party_list {

        regexp {(.*),(.*)} $pl match task_id_v num_value

        set t_id  $task_id_v
        set r_id  $assignment_role($pl)
        set p_id  $assignment_party($pl)

        set subject "New Task \#$t_id: $one_lines($t_id)"

        if {[string equal $use_uncertain_completion_times_p 1]} {
            set estimated_work "
Hrs work (min):  $est_hours_work_min($t_id)
Hrs work (max):  $est_hours_work_max($t_id)"
        } else {
            set estimated_work "
Hrs work:        $est_hours_work($t_id)"

}
        set notification_text "-------------
Task overview
-------------
Task ID:         \#$t_id
Description:     $one_lines($t_id)
Project:         $project_name
Your role:       $role_oneline($r_id)

---------------
Estimated work:
---------------$estimated_work

------
Dates:
------
Deadline:        [ad_decode $end_dates_pretty($t_id) "" "None" $end_dates_pretty($t_id)]
Earliest start:  $earliest_starts($item_id)
Earliest finish: $earliest_finishes($item_id)
Latest start:    $latest_starts($item_id)
Latest finish    $latest_finishes($item_id)

-----------
Description
-----------
$descriptions($t_id)"

        #notification::request::new \
        #    -type_id "[notification::type::get_type_id -short_name pm_task_notif]" \
        #    -object_id $t_id \
        #    -user_id $p_id \
        #    -interval_id [notification::interval::get_id_from_name -name instant] \
        #    -delivery_method_id [notification::delivery::get_id -short_name email]

        notification::new \
            -type_id [notification::type::get_type_id -short_name pm_task_notif] \
            -object_id $t_id \
            -response_id $t_id \
            -notif_subject $subject \
            -notif_text $notification_text

        db_dml add_assignment { }

    }
        
} -edit_data {

    # do something
    #role_id 
    #party_id

    if {[info exists role_id]} {
        
        set searchToken [array startsearch role_id]
        
        while {[array anymore role_id $searchToken]} {
            
            set keyname   [array nextelement role_id $searchToken]
            set keyvalu   $role_id($keyname)
            
            # keyname looks like 2308.1 - 2308.10
            # first element is task_id, second is 1-10
            # if keyvalu is not empty, then we pay attention to it.

            if {[exists_and_not_null keyvalu]} {

                regexp {(.*)\.(.*)} $keyname match task_id_val num_value

                set assignment_role($task_id_val,$num_value) $keyvalu

            }            
        }
        
    }

    set party_list [list]

    if {[info exists party_id]} {
        
        set searchToken [array startsearch party_id]
        
        while {[array anymore party_id $searchToken]} {
            
            set keyname   [array nextelement party_id $searchToken]
            set keyvalu   $party_id($keyname)
            
            # keyname looks like 2308.1 - 2308.10
            # first element is task_id, second is 1-10
             # if keyvalu is not empty, then we pay attention to it.

            if {[exists_and_not_null keyvalu]} {

                regexp {(.*)\.(.*)} $keyname match task_id_val num_value

                set assignment_party($task_id_val,$num_value) $keyvalu

                lappend party_list "$task_id_val,$num_value"

            }            
        }
      
    }

    db_dml delete_assignments { }

    foreach pl $party_list {

        regexp {(.*),(.*)} $pl match task_id_v num_value

        set t_id  $task_id_v
        set r_id  $assignment_role($pl)
        set p_id  $assignment_party($pl)

        db_dml add_assignment { }

    }
        
} -after_submit {

    ad_returnredirect "one?project_item_id=$project_item_id"
    ad_script_abort
}


# we create a terrible monster array

set index 0

foreach tiid $task_id {

    set roles_values [db_list_of_lists get_current_roles { }]
    set users_values [db_list_of_lists get_current_users { }]

    if {[exists_and_not_null process_task_id]} {
        set ptid [lindex $process_task_id $index]

        set roles_values [list]
        set users_values [list]

        db_foreach get_process_roles_assignments { } {
            lappend roles_values $rid
            lappend users_values $pid
        }

    }

    set users_length [string length $users_values]
    set roles_length [string length $roles_values]

    for {set i 0} {$i <= 5} {incr i} {

        if {$i < $users_length && $i < $roles_length} {
            set uv [lindex $users_values $i]
            set rv [lindex $roles_values $i]
        } else {
            set uv ""
            set rv ""
        }

        ad_form -extend -name add_edit -form \
            [list \
                 [list \
                      party_id.$tiid.$i:text(select) \
                      {label "Assignments \#$i $tiid"} \
                      {options {[set users_lofl]}} \
                      {values $uv} \
                     ] \
                 [list \
                      role_id.$tiid.$i:text(select) \
                      {label "Role \#$i $tiid"} \
                      {options {[set roles_lofl]}} \
                      {values $rv} \
                     ] \
                ] 
        
    }

    incr index
}


