ad_page_contract {

    Main view page for tasks.

    @author jader@bread.com
    @creation-date 2003-12-03
    @cvs-id $Id: tasks.tcl,v 1.1.2.10 2004/03/12 00:20:24 jader Exp $

    @return title Page title.
    @return context Context bar.
    @return tasks Multirow data set of tasks
    @return task_term Terminology for tasks
    @return task_term_lower Terminology for tasks (lower case)
    @return project_term Terminology for projects
    @return project_term_lower Terminology for projects (lower case)

} {
    orderby:optional
    party_id:optional
    {searchterm ""}
    {mine_p "t"}
    {status_id ""}
} -properties {
    task_term:onevalue
    context:onevalue
    tasks:multirow
}

# --------------------------------------------------------------- #

# terminology
set task_term       [parameter::get -parameter "TaskName" -default "Task"]
set task_term_lower [parameter::get -parameter "taskname" -default "task"]
set project_term    [parameter::get -parameter "ProjectName" -default "Project"]
set project_term_lower [parameter::get -parameter "projectname" -default "project"]

# set up context bar
set context [list "Tasks"]

# the unique identifier for this package
set package_id [ad_conn package_id]
set user_id    [ad_maybe_redirect_for_registration]

# if mine_p is true, show only my tasks
if {[string equal $mine_p t]} {
    set party_id $user_id
}

# status defaults to open
if {![exists_and_not_null status_id]} {
    set status_id [pm::task::default_status_open]
}

# permissions
permission::require_permission -party_id $user_id -object_id $package_id -privilege read

set write_p  [permission::permission_p -object_id $package_id -privilege write] 
set create_p [permission::permission_p -object_id $package_id -privilege create]
set admin_p [permission::permission_p -object_id $package_id -privilege admin]

# Tasks, using list-builder ---------------------------------

template::list::create \
    -name tasks \
    -multirow tasks \
    -key item_id \
    -elements {
        task_number {
            label "\#"
            link_url_col item_url
            link_html { title "View this project version" }
            display_template {<a href="@tasks.item_url@">@tasks.task_id@</a>}
        }
        title {
            label "Subject"
        }
        full_name {
            label "Who"
            display_template "<if @tasks.full_name@ nil><font color=\"red\">unassigned</font></if><else>@tasks.full_name@ (@tasks.role@)</else>"
        }
        slack_time {
            label "Slack time"
            display_template "<if @tasks.slack_time@ gt 1>@tasks.slack_time@</if><else><font color=\"red\">@tasks.slack_time@</font></else>"
        }
        latest_start_pretty {
            label "Latest Start"
        }
        latest_finish_pretty {
            label "Latest Finish"
        }
        actual_hours_worked {
            label "Hours completed"
            display_template "@tasks.actual_hours_worked@/@tasks.estimated_hours_work@"
        }
    } \
    -actions {
        "Add task" "task-select-project" "Add a task"
    } \
    -sub_class {
        narrow
    } \
    -filters {
        searchterm {
            label "Search"
        }

        party_id {
            label "People"
            values {[db_list_of_lists get_people "select distinct(first_names || ' ' || last_name) as fullname, u.person_id from persons u, pm_task_assignment a where u.person_id = a.party_id order by fullname"]}
            where_clause {
                ta.party_id = :party_id
            }
        }
        status_id {
            label "Status"
            values {[db_list_of_lists get_status_values "select description, status_id from pm_task_status order by status_type desc, description"]}
            where_clause {ts.status = :status_id}
        }

        mine_p {
            label "Show others' tasks"
        }
    } \
    -orderby {
        default_value latest_start_pretty,asc
        task_number {
            label "Task \#"
            orderby_desc "ts.task_number desc"
            orderby_asc "ts.task_number asc"
            default_direction asc
        }
        title {
            label "Subject"
            orderby_desc "t.title desc"
            orderby_asc "t.title asc"
            default_direction asc
        }
        full_name {
            label "Who"
            orderby_desc "p.first_names desc,p.last_name desc"
            orderby_asc "p.first_names, p.last_name"
            default_direction asc
        }
        description {
            label "Description"
            orderby_desc "t.description desc"
            orderby_asc "t.description"
            default_direction asc
        }
        slack_time {
            label "Slack"
            orderby_desc "(latest_start - earliest_start) desc"
            orderby_asc "(latest_start - earliest_start)"
            default_direction asc
        }
        latest_start_pretty {
            label "Latest start"
            orderby_desc "t.latest_start desc"
            orderby_asc "t.latest_start"
            default_direction asc
        }
        latest_finish_pretty {
            label "Latest finish"
            orderby_desc "t.latest_finish desc"
            orderby_asc "t.latest_finish"
            default_direction asc
        }
        actual_hours_worked {
            label "Hours completed"
            orderby_desc "t.actual_hours_worked desc"
            orderby_asc "t.actual_hours_worked"
            default_direction asc
        }
    } \
    -orderby_name orderby \
    -html {
        width 100%
    }


db_multirow -extend { item_url latest_start_pretty latest_finish_pretty slack_time} tasks tasks {
} {
    set item_url [export_vars -base "task-one" {task_id}]

    set latest_start_pretty [lc_time_fmt $latest_start "%x"]
    set latest_finish_pretty [lc_time_fmt $latest_finish "%x"]

    if {[exists_and_not_null earliest_start_j]} {
        set slack_time [pm::task::slack_time \
                            -earliest_start_j $earliest_start_j \
                            -today_j $today_j \
                            -latest_start_j $latest_start_j]
    } else {
        set slack_time "n/a"
    }


}


# ------------------------- END OF FILE ------------------------- #
